import LogUtil from "~/server/utils/log"

// 检测容器运行状态。如果服务器突然被关停，会导致个人服务一直显示“运行中”，但是实际停掉了
export default defineEventHandler(async (event) => {
  try {
    // 根据传入的端口号，检测
    let username = event.context.username
    let docker = createDockerFactory(username)
    let container = await docker.checkContainer('logwire_backend_helper.' + username + '.node')
    if (!container) {
      throw new Error('没有创建容器，请先初始化容器')
    }
    let info = await container.inspect()
    if (info.State.Running) {
      // 正在运行，则认为正常
      return
    } else {
      LogUtil.print(username, `[progress] [[1;34mInfo[m] 服务器异常关闭，正在重启...... \n`)
      await docker.startContainer({ container })
      // 依次打开 nginx, vscode-web
      try {
        await docker.execContainerCommand({ container, cmd: 'lsof -i:80' })
      } catch (err) {
        try {
          await docker.execContainerCommand({ container, cmd: 'nginx' })
          LogUtil.print(username, `[progress] [[1;34mInfo[m] Nginx 重启成功...... \n`)
        } catch (err) {
          throw err
        }
      }
      try {
        await docker.execContainerCommand({ container, cmd: 'lsof -i:8000' })
      } catch (err) {
        try {
          docker.execContainerCommand({ container, cmd: 'code-server --bind-addr 127.0.0.1:8000 --auth none' })
          LogUtil.print(username, `[progress] [[1;34mInfo[m] Vscode 重启成功...... \n`)
        } catch (err) {
          throw err
        }
      }

      try { await docker.execContainerCommand({ container, cmd: 'pm2 delete backend' }) } catch (err) {}
      try { await docker.execContainerCommand({ container, cmd: 'pm2 delete gateway' }) } catch (err) {}
      try { await docker.execContainerCommand({ container, cmd: 'pm2 delete platform' }) } catch (err) {}

      const status = getUserConfig(username, 'status')
      if (status === 'running') {
        setUserConfig(username, 'status', 'stopped')
      }

      const statusV1 = getUserConfig(username, 'v1-status')
      if (statusV1 === 'running') {
        setUserConfig(username, 'v1-status', 'stopped')
      }
      LogUtil.printSuccess(username, '所有服务重启成功')
    }
  } catch (err) {
    setResponseStatus(event, 500)
    return err
  }
})